==> coffee-new-0.0.3.tgz: package/lib/coffee-new-helper.js <==
(function() {
  var colors, cp, path, util;
  colors = require('colors');
  cp = require('child_process');
  path = require('path');
  util = require('util');
  exports.changeFileExtension = function(filePath, oldExtension, newExtension) {
    if (path.extname(filePath) !== oldExtension) {
      throw 'changeFileExtension Error: Path ' + filePath + ' does not have the extension ' + oldExtension + '.';
    }
    return path.resolve(path.dirname(filePath), path.basename(filePath, oldExtension) + newExtension);
  };
  exports.getMirrorPath = function(baseDirectoryPath, filePath, oldDirectoryName, newDirectoryName) {
    var oldPathPrefix, pathSuffix, startPos;
    oldPathPrefix = path.resolve(baseDirectoryPath, oldDirectoryName);
    startPos = oldPathPrefix.length;
    if (startPos > filePath.length) {
      throw 'getMirrorPath Error: baseDirectoryPath + oldDirectoryName should be shorter than filePath.';
    }
    if (filePath.slice(0, (startPos - 1 + 1) || 9e9) !== oldPathPrefix) {
      throw 'getMirrorPath Error: The prefix of filePath should match baseDirectoryPath + oldDirectoryName.';
    }
    pathSuffix = filePath.slice(startPos + 1, (filePath.length + 1) || 9e9);
    return path.resolve(baseDirectoryPath, newDirectoryName, pathSuffix);
  };
  exports.getRelativePath = function(basePath, longPath) {
    if (basePath[basePath.length - 1] !== '/') {
      basePath += '/';
    }
    if (basePath.length > longPath.length) {
      throw 'getPathSuffix Error: basePath should be shorter than longPath.';
    }
    if (longPath.slice(0, (basePath.length - 1 + 1) || 9e9) !== basePath) {
      throw 'getPathSuffix Error: The prefix of longPath should match basePath.';
    }
    return longPath.slice(basePath.length, (longPath.length + 1) || 9e9);
  };
  exports.run = function(cmd, args, finishedCallback) {
    var p;
    p = cp.spawn(cmd, args);
    p.stdout.on('data', function(data) {
      return process.stdout.write(data);
    });
    p.stderr.on('data', function(data) {
      return process.stderr.write(data);
    });
    return p.on('exit', function(exitCode) {
      var exitString;
      exitString = cmd + ' process exited with code ' + exitCode;
      if (exitCode !== 0) {
        util.log(exitString.red);
      } else {
        util.log(exitString.green);
      }
      if (finishedCallback != null) {
        return finishedCallback(exitCode);
      }
    });
  };
}).call(this);

==> coffee-new-0.0.4.tgz: package/lib/coffee-new-helper.js <==
(function() {
  var colors, cp, path, util;
  colors = require('colors');
  cp = require('child_process');
  path = require('path');
  util = require('util');
  exports.changeFileExtension = function(filePath, oldExtension, newExtension) {
    if (path.extname(filePath) !== oldExtension) {
      throw 'changeFileExtension Error: Path ' + filePath + ' does not have the extension ' + oldExtension + '.';
    }
    return path.resolve(path.dirname(filePath), path.basename(filePath, oldExtension) + newExtension);
  };
  exports.getMirrorPath = function(baseDirectoryPath, filePath, oldDirectoryName, newDirectoryName) {
    var oldPathPrefix, pathSuffix, startPos;
    oldPathPrefix = path.resolve(baseDirectoryPath, oldDirectoryName);
    startPos = oldPathPrefix.length;
    if (startPos > filePath.length) {
      throw 'getMirrorPath Error: baseDirectoryPath + oldDirectoryName should be shorter than filePath.';
    }
    if (filePath.slice(0, (startPos - 1 + 1) || 9e9) !== oldPathPrefix) {
      throw 'getMirrorPath Error: The prefix of filePath should match baseDirectoryPath + oldDirectoryName.';
    }
    pathSuffix = filePath.slice(startPos + 1, (filePath.length + 1) || 9e9);
    return path.resolve(baseDirectoryPath, newDirectoryName, pathSuffix);
  };
  exports.getRelativePath = function(basePath, longPath) {
    if (basePath[basePath.length - 1] !== '/') {
      basePath += '/';
    }
    if (basePath.length > longPath.length) {
      throw 'getPathSuffix Error: basePath should be shorter than longPath.';
    }
    if (longPath.slice(0, (basePath.length - 1 + 1) || 9e9) !== basePath) {
      throw 'getPathSuffix Error: The prefix of longPath should match basePath.';
    }
    return longPath.slice(basePath.length, (longPath.length + 1) || 9e9);
  };
  exports.run = function(cmd, args, callback) {
    var p;
    p = cp.spawn(cmd, args);
    p.stdout.on('data', function(data) {
      return process.stdout.write(data);
    });
    p.stderr.on('data', function(data) {
      return process.stderr.write(data);
    });
    return p.on('exit', function(code) {
      var exitString;
      exitString = cmd + ' process exited with code ' + code;
      if (code !== 0) {
        util.log(exitString.red);
      } else {
        util.log(exitString.green);
      }
      if (callback != null) {
        return callback();
      }
    });
  };
}).call(this);
